pub unsafe extern "C" fn mbuf_coded_video_frame_finalize(
frame: *mut mbuf_coded_video_frame,
) -> c_intExpand description
Finalize a frame.
A finalized frame can no longer be modified with mbuf_coded_video_frame_add_nalu(), and allow read-only access to the data with mbuf_coded_video_frame_get_nalu() and mbuf_coded_video_frame_get_packed_buffer(). A frame can only be finalized if it contains at least one nalu.
@note Any memory associated with a finalized frame should not have its content modified. The library cannot check that, and it is the responsibility of the caller to ensure this.
@param frame: The frame.
@return 0 on success, negative errno on error.