pub unsafe extern "C" fn pomp_buffer_cread(
buf: *const pomp_buffer,
pos: *mut usize,
cdata: *mut *const c_void,
len: usize,
) -> c_intExpand description
Read data from buffer without copy. @param buf : buffer. @param pos : read position. It will be updated in case of success. @param cdata : will receive pointer to data inside buffer. It is valid as long as the buffer is valid and no write or resize operation is performed. @param len : number of bytes to read. @return 0 in case of success, negative errno value in case of error.