pub unsafe extern "C" fn pomp_buffer_set_len(
buf: *mut pomp_buffer,
len: usize,
) -> c_intExpand description
Set the used length of the buffer. @param buf : buffer. @param len : used length of data (shall be lesser than allocated size). @return 0 in case of success, negative errno value in case of error. -EPERM is returned if the buffer is shared (ref count is greater than 1) or readonly.