pomp_ctx_process_fd

Function pomp_ctx_process_fd 

pub unsafe extern "C" fn pomp_ctx_process_fd(
    ctx: *mut pomp_ctx,
) -> c_int
Function to be called when the loop of the context is signaled. @param ctx : context. @return 0 in case of success, negative errno value in case of error. @remarks this is equivalent to calling pomp_ctx_wait_and_process with a timeout of 0 (no wait).