pub unsafe extern "C" fn pomp_ctx_stop(ctx: *mut pomp_ctx) -> c_intExpand description
Stop the context. It will disconnects all peers (with notification). The context structure itself is not freed. It can be used again with listen or connect. @param ctx : context. @return 0 in case of success, negative errno value in case of error.