pomp_loop_wait_and_process

Function pomp_loop_wait_and_process 

pub unsafe extern "C" fn pomp_loop_wait_and_process(
    loop_: *mut pomp_loop,
    timeout: c_int,
) -> c_int
Wait for events to occur in loop and process them. @param loop : loop. @param timeout : timeout of wait (in ms) or -1 for infinite wait. @return 0 in case of success, -ETIMEDOUT if timeout occurred, negative errno value in case of error.