vdef_rect_align

Function vdef_rect_align 

pub unsafe extern "C" fn vdef_rect_align(
    rect: *mut vdef_rect,
    align: *const vdef_rect,
    align_lower: bool,
    enlarge: bool,
)
Align components of a rectangle. @param rect: the rectangle to align @param align: the rectangle with restriction to apply @param align_lower: true to align left and top on lower values, false to align on upper values @param enlarge: true to enlarge the rectangle, false to shrink the rectangle