vmeta_session_date_read

Function vmeta_session_date_read 

pub unsafe extern "C" fn vmeta_session_date_read(
    str_: *const c_char,
    date: *mut time_t,
    gmtoff: *mut c_long,
) -> c_int
Read a date string. The date is returned through the date and gmtoff parameters. date is a value in seconds since the Epoch (1970-01-01 00:00:00 +0000 UTC); gmtoff is the GMT offset in seconds east (eg. GMT-6 is -21600). @param str: pointer to the string to read @param date: pointer to the date in seconds since the Epoch (output) @param gmtoff: pointer to the GMT offset in seconds increasing eastbound (output) @return 0 on success, negative errno value in case of error