vmeta_session_thermal_alignment_write

Function vmeta_session_thermal_alignment_write 

pub unsafe extern "C" fn vmeta_session_thermal_alignment_write(
    str_: *mut c_char,
    len: usize,
    align: *const vmeta_thermal_alignment,
) -> isize
Write a thermal camera alignment parameters string. The str string must have been previously allocated. The function writes up to len chars. @param str: pointer to the string to write to (output) @param len: maximum length of the string @param align: pointer to a thermal camera alignment parameters structure @return the length of the string written on success, negative errno value in case of error