h264_mb_type

Type Alias h264_mb_type 

pub type h264_mb_type = c_uint;
7.4.5 Macroblock layer semantics Actual value is not part of the specification UNKNOWN is also not part of the specification but added for convenience