pomp_send_cb_t

Type Alias pomp_send_cb_t 

pub type pomp_send_cb_t = Option<unsafe extern "C" fn(ctx: *mut pomp_ctx, conn: *mut pomp_conn, buf: *mut pomp_buffer, status: u32, cookie: *mut c_void, userdata: *mut c_void)>;
Send callback. If set, it is called to indicate that the given buffer has been sent (or not). @param ctx : context. @param conn : connection on which the event occurred. @param buf : buffer whose send status id notified. If in raw mode is it the one given in send operation, otherwise it is the internal buffer associated with the message sent. @param status : set of flags (enum pomp_send_status) indicating the status. one of OK, ERROR or ABORTED is always set. QUEUE_EMPTY indicates that there is no more buffer queued internally. @param cookie : NULL, reserved for future use. @param userdata : user data given in pomp_ctx_new.

Aliased Type

pub enum pomp_send_cb_t {
    None,
    Some(unsafe extern "C" fn(*mut pomp_ctx, *mut pomp_conn, *mut pomp_buffer, u32, *mut c_void, *mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut pomp_ctx, *mut pomp_conn, *mut pomp_buffer, u32, *mut c_void, *mut c_void))

Some value of type T.