pub unsafe extern "C" fn h265_bs_write_bits(
bs: *mut h265_bitstream,
v: u32,
n: u32,
) -> c_intExpand description
Write bits to the stream.
@param bs Bitstream handle @param v Bit mask. The n least significant bits of the mask are inserted in most significant to least significant order @param n Number of bits to extract from v into the stream
@return Number of bits written on success, negative errno value in case of error