pub unsafe extern "C" fn mbuf_ancillary_data_get_buffer(
data: *mut mbuf_ancillary_data,
len: *mut usize,
) -> *const c_voidExpand description
Get the buffer of an ancillary data.
If the data contains a string value, the returned pointer will equal to the return value of mbuf_ancillary_data_get_string(data), and len will be set to strlen(string_value)+1.
@note The returned value is valid only while the caller holds a reference on data.
@param data: The ancillary data. @param len: [out] The buffer length.
@return A valid pointer to the data buffer on success, NULL on error.