pub unsafe extern "C" fn mbuf_ancillary_data_get_string(
data: *mut mbuf_ancillary_data,
) -> *const c_charExpand description
Get the string value of an ancillary data.
This function returns NULL if the data does not contains a string value.
@note The returned value is valid only while the caller holds a reference on data.
@param data: The ancillary data.
@return A NULL-terminated string containing the data value, or NULL on error.