pub unsafe extern "C" fn mbuf_coded_video_frame_copy(
frame: *mut mbuf_coded_video_frame,
dst: *mut mbuf_mem,
ret_obj: *mut *mut mbuf_coded_video_frame,
) -> c_intExpand description
Copy a frame into a new one, backed by the given memory.
The memory must be big enough to hold the whole frame. The required size can be retrieved from a frame with the mbuf_coded_video_frame_get_packed_size() call. The returned frame is not finalized and can be modified by the caller.
All ancillary data attached to `frame’ will be copied to the new frame.
@note The new frame will be properly packed for mbuf_coded_video_frame_get_packed_buffer()
@param frame: The frame to copy. @param dst: The memory for the new frame. @param ret_obj: [out] The new frame.
@return 0 on success, negative errno on error.