pub unsafe extern "C" fn mbuf_coded_video_frame_set_callbacks(
frame: *mut mbuf_coded_video_frame,
cbs: *mut mbuf_coded_video_frame_cbs,
) -> c_intExpand description
Set the optional callback functions for a coded frame.
The cbs structure is copied internally and doesn’t need to stay valid for the lifetime of the frame. The callback functions can only be set until the frame is finalized by calling mbuf_coded_video_frame_finalize().
@param frame: The frame. @param cbs: Callback functions.
@return 0 on success, negative errno on error.