pub unsafe extern "C" fn pomp_ctx_send(
ctx: *mut pomp_ctx,
msgid: u32,
fmt: *const c_char,
...
) -> c_intExpand description
Format and send a message to a context. For server it will broadcast to all connected clients. If there is no connection, no message is sent and no error is returned. For client, if there is no connection, -ENOTCONN is returned. @param ctx : context. @param msgid : message id. @param fmt : format string. Can be NULL if no arguments given. @param … : message arguments. @return 0 in case of success, negative errno value in case of error.
@remarks the operation will be queued automatically for later processing in case the underlying socket buffer is full. Use ‘pomp_ctx_set_socket_cb’ to have more information about completion.