pub unsafe extern "C" fn pomp_ctx_setup_keepalive(
ctx: *mut pomp_ctx,
enable: c_int,
idle: c_int,
interval: c_int,
count: c_int,
) -> c_intExpand description
Setup TCP keepalive. Settings will be applied to all future TCP connections. Current connections (if any) will not be affected. @param ctx : context. @param enable : 1 to enable, 0, to disable. @param idle : start keepalives after this period (in seconds). @param interval : Interval between keepalives (in seconds). @param count : number of keepalives before death. @return 0 in case of success, negative errno value in case of error.
@remarks Default values if nothing else is specified is (1, 5, 1, 2).