pub unsafe extern "C" fn pomp_decoder_read_cstr(
dec: *mut pomp_decoder,
v: *mut *const c_char,
) -> c_intExpand description
Decode a string without any extra allocation or copy. @param dec : decoder. @param v : decoded string. Shall NOT be modified or freed as it points directly to internal storage. Scope is the same as the associated message. @return 0 in case of success, negative errno value in case of error.