pub unsafe extern "C" fn pomp_msg_adump(
msg: *const pomp_msg,
dst: *mut *mut c_char,
) -> c_intExpand description
Dump a message in a human readable form. Similar to pomp_msg_dump() but allocates the output buffer dynamically. Dump a message in a human readable form. @param msg : message. @param dst : destination buffer, which will be allocated to a suitable size dynamically. Must be freed with free(), after usage. @return 0 in case of success, negative errno value in case of error.