pub unsafe extern "C" fn pomp_prot_decode_msg(
prot: *mut pomp_prot,
buf: *const c_void,
len: usize,
msg: *mut *mut pomp_msg,
) -> c_intExpand description
Try to decode a message with given input data. @param prot : protocol decoder. @param buf : input data. @param len : size of input data. @param msg : will receive decoded message. If more input data is required to decode the message, NULL will be returned. The message needs to be released either by calling ‘pomp_msg_destroy’ or ‘pomp_prot_release_msg’. Calling ‘pomp_prot_release_msg’ allows reuse of allocated message structure. @return number of bytes processed. It can be less that input size in which case caller shall call again this function with remaining bytes.